@@ -5,6 +5,7 @@ package platform
 import (
 	"errors"
 	"os"
+	"strconv"
 	"strings"
 	"time"
 
@@ -23,17 +24,24 @@ func (env *Shell) Home() string {
 	return os.Getenv("HOME")
 }
 
-func (env *Shell) QueryWindowTitles(processName, windowTitleRegex string) (string, error) {
+func (env *Shell) QueryWindowTitles(_, _ string) (string, error) {
 	return "", &NotImplemented{}
 }
 
 func (env *Shell) IsWsl() bool {
 	defer env.Trace(time.Now())
-	// one way to check
-	// version := env.FileContent("/proc/version")
-	// return strings.Contains(version, "microsoft")
-	// using env variable
-	return env.Getenv("WSL_DISTRO_NAME") != ""
+	const key = "is_wsl"
+	if val, found := env.Cache().Get(key); found {
+		env.Debug(val)
+		return val == "true"
+	}
+	var val bool
+	defer func() {
+		env.Cache().Set(key, strconv.FormatBool(val), -1)
+	}()
+	val = env.HasCommand("wslpath")
+	env.Debug(strconv.FormatBool(val))
+	return val
 }
 
 func (env *Shell) IsWsl2() bool {
@@ -97,7 +105,7 @@ func (env *Shell) CachePath() string {
 	return env.Home()
 }
 
-func (env *Shell) WindowsRegistryKeyValue(path string) (*WindowsRegistryValue, error) {
+func (env *Shell) WindowsRegistryKeyValue(_ string) (*WindowsRegistryValue, error) {
 	return nil, &NotImplemented{}
 }
 
@@ -124,7 +132,7 @@ func (env *Shell) ConvertToLinuxPath(path string) string {
 	return path
 }
 
-func (env *Shell) LookWinAppPath(file string) (string, error) {
+func (env *Shell) LookWinAppPath(_ string) (string, error) {
 	return "", errors.New("not relevant")
 }
 
@@ -133,7 +141,7 @@ func (env *Shell) DirIsWritable(path string) bool {
 	return unix.Access(path, unix.W_OK) == nil
 }
 
-func (env *Shell) Connection(connectionType ConnectionType) (*Connection, error) {
+func (env *Shell) Connection(_ ConnectionType) (*Connection, error) {
 	// added to disable the linting error, we can implement this later
 	if len(env.networks) == 0 {
 		return nil, &NotImplemented{}
