@@ -3,7 +3,7 @@ package template
 import (
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 )
 
 type Logic string
